==> aws-cdk-scala_2.12-0.5.1-sources.jar: io/burkard/cdk/services/codedeploy/LambdaDeploymentGroup.scala <==
package io.burkard.cdk.services.codedeploy

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object LambdaDeploymentGroup {

  def apply(
    internalResourceId: String,
    alias: software.amazon.awscdk.services.lambda.Alias,
    application: Option[software.amazon.awscdk.services.codedeploy.ILambdaApplication] = None,
    deploymentConfig: Option[software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig] = None,
    role: Option[software.amazon.awscdk.services.iam.IRole] = None,
    ignorePollAlarmsFailure: Option[Boolean] = None,
    autoRollback: Option[software.amazon.awscdk.services.codedeploy.AutoRollbackConfig] = None,
    alarms: Option[List[_ <: software.amazon.awscdk.services.cloudwatch.IAlarm]] = None,
    preHook: Option[software.amazon.awscdk.services.lambda.IFunction] = None,
    deploymentGroupName: Option[String] = None,
    postHook: Option[software.amazon.awscdk.services.lambda.IFunction] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.codedeploy.LambdaDeploymentGroup =
    software.amazon.awscdk.services.codedeploy.LambdaDeploymentGroup.Builder
      .create(stackCtx, internalResourceId)
      .alias(alias)
      .application(application.orNull)
      .deploymentConfig(deploymentConfig.orNull)
      .role(role.orNull)
      .ignorePollAlarmsFailure(ignorePollAlarmsFailure.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .autoRollback(autoRollback.orNull)
      .alarms(alarms.map(_.asJava).orNull)
      .preHook(preHook.orNull)
      .deploymentGroupName(deploymentGroupName.orNull)
      .postHook(postHook.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.19.0-sources.jar: io/burkard/cdk/services/codedeploy/LambdaDeploymentGroup.scala <==
package io.burkard.cdk.services.codedeploy

import scala.collection.JavaConverters._

@scala.annotation.nowarn("cat=deprecation")
@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object LambdaDeploymentGroup {

  def apply(
    internalResourceId: String,
    alias: software.amazon.awscdk.services.lambda.Alias,
    application: Option[software.amazon.awscdk.services.codedeploy.ILambdaApplication] = None,
    deploymentConfig: Option[software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig] = None,
    role: Option[software.amazon.awscdk.services.iam.IRole] = None,
    ignorePollAlarmsFailure: Option[Boolean] = None,
    autoRollback: Option[software.amazon.awscdk.services.codedeploy.AutoRollbackConfig] = None,
    alarms: Option[List[_ <: software.amazon.awscdk.services.cloudwatch.IAlarm]] = None,
    preHook: Option[software.amazon.awscdk.services.lambda.IFunction] = None,
    deploymentGroupName: Option[String] = None,
    postHook: Option[software.amazon.awscdk.services.lambda.IFunction] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.codedeploy.LambdaDeploymentGroup =
    software.amazon.awscdk.services.codedeploy.LambdaDeploymentGroup.Builder
      .create(stackCtx, internalResourceId)
      .alias(alias)
      .application(application.orNull)
      .deploymentConfig(deploymentConfig.orNull)
      .role(role.orNull)
      .ignorePollAlarmsFailure(ignorePollAlarmsFailure.map(Boolean.box).orNull)
      .autoRollback(autoRollback.orNull)
      .alarms(alarms.map(_.asJava).orNull)
      .preHook(preHook.orNull)
      .deploymentGroupName(deploymentGroupName.orNull)
      .postHook(postHook.orNull)
      .build()
}
